/*----------------------------------------------------------------------------
 * Name:    demo.c
 * Purpose: USB HID Demo
 * Note(s): 
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2009-2011 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "STM32F10x.h"                            /* STM32F10x definitions    */

#include "type.h"

#include "usb.h"
#include "usbcfg_STM32F10x.h"
#include "usbhw_STM32F10x.h"

//#include "LCD.h"
#include "demo.h"


U8 InReport;                                      /* HID Input Report         */
                                                  /*   Bit0..1: Buttons       */
                                                  /*   Bit2..7: Reserved      */

U8 OutReport;                                     /* HID Out Report           */
                                                  /*   Bit0..7: LEDs          */


/*----------------------------------------------------------------------------
  Get HID Input Report -> InReport
 *----------------------------------------------------------------------------*/
void GetInReport (void) {

	InReport = 0x00;
  if ((GPIOB->IDR & 0x8000) == 0) InReport |= 0x01;   /* S2 pressed means 0       */
}


/*----------------------------------------------------------------------------
  Set HID Output Report <- OutReport
 *----------------------------------------------------------------------------*/
void SetOutReport (void) {

		if (OutReport & 0x01)
			GPIOB->ODR	 |=	 0x20;
		else
			GPIOB->ODR	 &=	 ~0x20;
}


/*----------------------------------------------------------------------------
  MAIN function
 *----------------------------------------------------------------------------*/
int main (void) {
  /* configure LEDs */
  RCC->APB2ENR |= (1UL << 3);                     /* Enable GPIOB clock       */

	GPIOB->CRL   &= ~0xFFFFFFFF;                    /* PB.0..7 clear           */
  GPIOB->CRL   |=  0x33333333;                    /* PB.0..7 is output       */
	
	GPIOB->CRL   &= ~0xFFFFFFFF;                    /* PB.8..15 clear           */
  GPIOB->CRL   |=  0x83333333;                    /* PB15 is input       */
	GPIOB->ODR	 |=	 0x8000;
	
  USB_Init();                                     /* USB Initialization       */
  USB_Connect(__TRUE);                            /* USB Connect              */

  while (1);                                      /* Loop forever             */
}
